@@ -4,7 +4,6 @@ import os
 import json
 import datetime
 import subprocess
-import errno
 
 import yaml
 import tornado.web
@@ -66,29 +65,14 @@ class Processor(object):
         self.application.ioloop.add_timeout(self.application.interval, self.application.next)
 
     def wait(self):
-        try:
-            pid, sts = subprocess._eintr_retry_call(os.waitpid, self.process.pid, 0)
-        except OSError as e:
-            if e.errno != errno.ECHILD:
-                raise
-
-            pid = self.process.pid
-            sts = 0
-
-        if pid == self.process.pid:
-            try:
-                self.process._handle_exitstatus(sts)
-            except RuntimeError:
-                pass
-
-        return_code = self.process.returncode
-
-        if return_code is None:
+        pid, status = os.waitpid(self.process.pid, os.WNOHANG)
+        if pid == 0:
             self.application.ioloop.add_timeout(self.application.interval, self.wait)
-        elif return_code == 0:
-            self.application.ioloop.add_timeout(self.application.interval, self.next)
         else:
-            self.error(return_code)
+            if status == 0:
+                self.application.ioloop.add_timeout(self.application.interval, self.next)
+            else:
+                self.error(status)
 
 
 class Application(tornado.web.Application):
